@@ -13,14 +13,14 @@ class Mongo:
         self,
         aws_access_key_id,
         aws_secret_access_key,
-        mongo_cluster="dev-data-team-cluster",
+        mongo_cluster,
         max_pool_size=64,
     ):
         access_key_id = quote_plus(aws_access_key_id)
         secret_access_key = quote_plus(aws_secret_access_key)
         cluster = quote_plus(mongo_cluster)
 
-        uri = "mongodb+srv://%s:%s@%s.drpqa.mongodb.net/?authSource=$external&authMechanism=MONGODB-AWS&retryWrites=true&w=majority" % (
+        uri = "mongodb+srv://%s:%s@%s/?authSource=$external&authMechanism=MONGODB-AWS&retryWrites=true&w=majority" % (
             access_key_id,
             secret_access_key,
             cluster,
